import { isBrowser, isDev } from './env';
import { errorOnce, warnOnce } from './logger';
export class NullRuleManager {
    // eslint-disable-next-line class-methods-use-this
    increaseUsage() {
        if (isDev) {
            // TODO: Add instructions for resolving the situation
            if (isBrowser) {
                errorOnce('Client-side injection of dynamic styles is not set up. Wrap the component tree inside a `<StyleInjectorProvider>` without parameters.');
            }
            else {
                warnOnce('Server-side rendering of dynamic styles is not configured properly. Some of the initially applied CSS could not be prerendered. Please refer to the documentation at https://glaze.js.org/docs/server-side-rendering for further information.');
            }
        }
    }
    // eslint-disable-next-line class-methods-use-this
    decreaseUsage() { }
}
export class OptimizedRuleManager {
    constructor(injector, initialRuleIndexesByClassName) {
        this.ruleIndexesByClassName = new Map();
        this.usageCountsByClassName = new Map();
        this.injector = injector;
        this.ruleIndexesByClassName = initialRuleIndexesByClassName;
    }
    increaseUsage(className, cssText) {
        const prevUsageCount = this.usageCountsByClassName.get(className) || 0;
        this.usageCountsByClassName.set(className, prevUsageCount + 1);
        // Append new rule only if it wasn't available in the server-rendered code
        if (!prevUsageCount && !this.ruleIndexesByClassName.has(className)) {
            this.ruleIndexesByClassName.set(className, this.injector.addRule(cssText()));
        }
    }
    decreaseUsage(className, byAmount) {
        const nextUsageCount = 
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        this.usageCountsByClassName.get(className) - byAmount;
        if (nextUsageCount) {
            this.usageCountsByClassName.set(className, nextUsageCount);
        }
        else {
            this.usageCountsByClassName.delete(className);
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            this.injector.nullifyRule(this.ruleIndexesByClassName.get(className));
            this.ruleIndexesByClassName.delete(className);
        }
    }
}
//# sourceMappingURL=RuleManager.js.map