/* Prefer performance over elegance, as this code is critical for the runtime */
import { useStyles } from 'react-treat';
import { useTheme } from './ThemeContext';
import { useStyleInjector } from './useStyleInjector';
import styleRefs from './useStyling.treat';
export function useStyling() {
    const theme = useTheme();
    const staticClassNames = useStyles(styleRefs);
    const getDynamicClassName = useStyleInjector();
    return function sx(themedStyle) {
        let className = '';
        // eslint-disable-next-line guard-for-in, no-restricted-syntax
        for (const alias in themedStyle) {
            // TODO: Remove type assertion if possible
            const value = themedStyle[alias];
            if (value != null) {
                const shorthand = theme.aliases[alias] || alias;
                // eslint-disable-next-line no-loop-func
                (theme.shorthands[shorthand] || [shorthand]).forEach((property) => {
                    // TODO: Support selectors and media queries
                    if (typeof value !== 'object') {
                        const identName = `${property}-${value}`;
                        className += ` ${staticClassNames[identName] ||
                            getDynamicClassName(identName, property, value)}`;
                    }
                });
            }
        }
        // Remove prepended whitespace
        return className.slice(1);
    };
}
//# sourceMappingURL=useStyling.js.map